pub struct StreamFetchRequest {
pub stream_id: Uuid,
pub source_key: String,
pub since: Option<DateTime<Utc>>,
}Expand description
Asks a backend for readings for one stream since a cursor.
Fields
stream_id: Uuidsource_key: Stringsince: Option<DateTime<Utc>>Last known reading time. None on a new stream or a full sync.